$(function () {
    var csInterface = new CSInterface();
    
    // Update the color of the panel when the theme color of the product changed.
    updateThemeWithAppSkinInfo(csInterface.hostEnvironment.appSkinInfo);

    // Listen for color theme change.
    csInterface.addEventListener(CSInterface.THEME_COLOR_CHANGED_EVENT, onAppThemeColorChanged);

    // Listen for Update Structural Design.
    csInterface.addEventListener("com.adobe.csxs.events.illustratorimpactui.UpdateLiveLink", updateLiveLink);

    // Listen for change to the auto update check box.
    $("#LiveLinkAutoUpdateCB").change(liveLinkAutoUpdateCBChange);

    // Listen for connect/disconnect button click.
    $("#LiveLinkConnectDisconnectBtn").click(liveLinkConnectDisconnectBtnClick);

    // Listen for open button click.
    $("#LiveLinkOpenBtn").click(liveLinkOpenBtnClick);

    // Listen for update impact button click.
    $("#LiveLinkUpdateImpactBtn").click(liveLinkUpdateImpactBtnClick);

    // Listen for change to the graphic quality combo box.
    $("#LiveLinkGraphicQualityCombo").change(liveLinkGraphicQualityChange);

    csInterface.setWindowTitle("Live Link");

    var liveLinkReady = new CSEvent('com.adobe.csxs.events.illustratorimpactui.LiveLinkReady', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.livelink');
    liveLinkReady.data = csInterface.isWindowVisible();
    csInterface.dispatchEvent(liveLinkReady);
});

var connectingLabelString = "Connecting...";
var status = '0';

/// <summary>
/// Update the live link panel with values from the dictionary.
/// </summary>
function updateLiveLink(event) {
    var xmlData = $.parseXML(event.data);
    var $xml = $(xmlData);

    var statusText = $xml.find('statusText').text();
    $("#LiveLinkStatusText").text(statusText);
    var connectLabel = $xml.find('connectLabel').text();
    $("#LiveLinkConnectDisconnectBtn").text(connectLabel);
    var openLabel = $xml.find('openLabel').text();
    $("#LiveLinkOpenBtn").text(openLabel);
    var updateImpactLabel = $xml.find('updateImpactLabel').text();
    $("#LiveLinkUpdateImpactBtn").text(updateImpactLabel);
    var autoUpdateLabel = $xml.find('autoUpdateLabel').text();
    $("#LiveLinkAutoUpdateLabel").text(autoUpdateLabel);
    var graphicQualityLabel = $xml.find('graphicQualityLabel').text();
    $("#LiveLinkGraphicQualityLabel").text(graphicQualityLabel);
    var lowLabel = $xml.find('graphicQualityLowLabel').text();
    $("#GraphicQualityOptionLow").text(lowLabel);
    var mediumLabel = $xml.find('graphicQualityMediumLabel').text();
    $("#GraphicQualityOptionMedium").text(mediumLabel);
    var highLabel = $xml.find('graphicQualityHighLabel').text();
    $("#GraphicQualityOptionHigh").text(highLabel);
    var veryHighLabel = $xml.find('graphicQualityVeryHighLabel').text();
    $("#GraphicQualityOptionVeryHigh").text(veryHighLabel);
    var activeLayerLabel = $xml.find('activeLayerLabel').text();
    $("#LiveLinkActiveLayerLabel").text(activeLayerLabel);
    var activeLayerText = $xml.find('activeLayerText').text();
    $("#LiveLinkActiveLayerText").text(activeLayerText);
    
    var activeLayerIsOneUp = $xml.find('activeLayerIsOneUp').text();

    status = $xml.find('status').text();
    if (status == '0') {
        $("#LiveLinkConnectDisconnectBtn").prop('disabled', false);
        $("#LiveLinkOpenBtn").prop('disabled', true);
        $("#LiveLinkUpdateImpactBtn").prop('disabled', true);

        $("#LiveLinkStatusIndicator").removeClass("connected");
        $("#LiveLinkStatusIndicator").removeClass("waiting");

        $("#LiveLinkStatusIndicator").addClass("disabled");
    }
    else if (status == '1') {
        $("#LiveLinkConnectDisconnectBtn").prop('disabled', false);
        $("#LiveLinkUpdateImpactBtn").prop('disabled', true);

        $("#LiveLinkStatusIndicator").removeClass("connected");
        $("#LiveLinkStatusIndicator").removeClass("disabled");

        $("#LiveLinkStatusIndicator").addClass("waiting");

        if (activeLayerIsOneUp == "true") {
            $("#LiveLinkOpenBtn").prop('disabled', false);
        }
        else {
            $("#LiveLinkOpenBtn").prop('disabled', true);
        }
    }
    else {
        $("#LiveLinkConnectDisconnectBtn").prop('disabled', false);
        $("#LiveLinkOpenBtn").prop('disabled', true);
        $("#LiveLinkUpdateImpactBtn").prop('disabled', false);

        $("#LiveLinkStatusIndicator").removeClass("disabled");
        $("#LiveLinkStatusIndicator").removeClass("waiting");

        $("#LiveLinkStatusIndicator").addClass("connected");
    }

    var autoUpdate = $xml.find('autoUpdate').text();
    if (autoUpdate == 'true')
        $("#LiveLinkAutoUpdateCB").prop('checked', true);
    else
        $("#LiveLinkAutoUpdateCB").prop('checked', false);

    var graphicQuality = $xml.find('graphicQuality').text();
    $("#LiveLinkGraphicQualityCombo").val(graphicQuality);

    var windowTitle = $xml.find('windowTitle').text();
    new CSInterface().setWindowTitle(windowTitle);
}

/// <summary>
/// Connects or disconnects the live link from Impact.
/// </summary>
function liveLinkConnectDisconnectBtnClick(event) {
    if (status == '0') {
        $("#LiveLinkStatusText").text(connectingLabelString);
        $("#LiveLinkConnectDisconnectBtn").prop('disabled', true);
    }

    var connectDisconnectEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.LiveLinkConnectDisconnectButtonClick', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.livelink');
    
    new CSInterface().dispatchEvent(connectDisconnectEvent);
}

/// <summary>
/// Pulls the active layer from Impact.
/// </summary>
function liveLinkOpenBtnClick(event) {
    var openEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.LiveLinkOpenButtonClick', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.livelink');

    new CSInterface().dispatchEvent(openEvent);
}

/// <summary>
/// Updates the relevant layer with the graphics from Illustrator.
/// </summary>
function liveLinkUpdateImpactBtnClick(event) {
    var updateImpactEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.LiveLinkUpdateImpactButtonClick', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.livelink');

    new CSInterface().dispatchEvent(updateImpactEvent);
}

/// <summary>
/// Sets whether or not the live link should auto update Impact on save.
/// </summary>
function liveLinkAutoUpdateCBChange(event) {
    var autoUpdateCBChangeEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.LiveLinkAutoUpdateCBChange', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.livelink');

    var autoUpdate = $("#LiveLinkAutoUpdateCB").is(':checked');
    var data = '<payload><autoUpdate>' + autoUpdate + '</autoUpdate></payload>';

    autoUpdateCBChangeEvent.data = data;

    new CSInterface().dispatchEvent(autoUpdateCBChangeEvent);
}

/// <summary>
/// Sets the graphic quality.
/// </summary>
function liveLinkGraphicQualityChange(event) {
    
    var graphicQualityComboChangeEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.LiveLinkGraphicQualityComboChange', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.livelink');
    
    var graphicQuality = $("#LiveLinkGraphicQualityCombo").val();

    var data = '<payload><graphicQuality>' + graphicQuality + '</graphicQuality></payload>';

    graphicQualityComboChangeEvent.data = data;

    new CSInterface().dispatchEvent(graphicQualityComboChangeEvent);
}