/// <summary>
/// Updates the theme based on the app skin info.
/// </summary>
function updateThemeWithAppSkinInfo(appSkinInfo) {

    var panelBackgroundColorHex = toHex(appSkinInfo.panelBackgroundColor.color);	
	
    document.body.bgColor = panelBackgroundColorHex;
    document.body.style.setProperty('--color-base',panelBackgroundColorHex);
	
    var highlightColor = "#ffffff";
    var accentColor = "#c7c7c7";
    var infoLabelColor = "#ffffff";
    var inputBorderColor = "#7A7A7A";
    var insetColor = "#454545";
    var insetSelectedColor = "#FFFFFF";
    var disabledBackgroundColor = "#595959";
    var disabledTextColor = "#747474";
	
    // Darkest
    if (panelBackgroundColorHex == "#323232"){
        accentColor = "#cdcdcd";
        infoLabelColor = "#999999";
        highlightColor = "#999999";
        inputBorderColor = "#3e3e3e";
        insetColor = "#262626";
        insetSelectedColor = "#FCFCFC";
        disabledBackgroundColor = "#393939";
        disabledTextColor = "#525252";
    }
    // Dark
    else if (panelBackgroundColorHex == "#535353") {
        accentColor = "#ffffff";
        infoLabelColor = "#c7c7c7";
        highlightColor = "#c7c7c7";
        inputBorderColor = "#5F5F5F";
        insetColor = "#454545";
        insetSelectedColor = "#FFFFFF";
        disabledBackgroundColor = "#595959";
        disabledTextColor = "#747474";
    }
    // Light
    else if (panelBackgroundColorHex == "#b8b8b8") {
        accentColor = "#232323";
        infoLabelColor = "#000000";
        highlightColor = "#4a4a4a";
        inputBorderColor = "#A8A8A8";
        insetColor = "#E3E3E3";
        insetSelectedColor = insetColor;
        disabledBackgroundColor = "#B0B0B0";
        disabledTextColor = "#8F8F8F";
    }
    // Lightest
    else if (panelBackgroundColorHex == "#f0f0f0") {
        accentColor = "#484848";
        infoLabelColor = "#000000";
        highlightColor = "#6d6d6d";
        inputBorderColor = "#DCDCDC";
        insetColor = "#FFFFFF";
        insetSelectedColor = insetSelectedColor;
        disabledBackgroundColor = "#E6E6E6";
        disabledTextColor = "#BDBDBD";
    }

    document.body.style.setProperty('--color-accent', accentColor);
    document.body.style.setProperty('--color-highlight', highlightColor);
    document.body.style.setProperty('--color-infoLabel', infoLabelColor);
    document.body.style.setProperty('--color-inputborder',inputBorderColor);
    document.body.style.setProperty('--color-inset',insetColor);	
    document.body.style.setProperty('--color-insetselected',insetSelectedColor);	
    document.body.style.setProperty('--color-disabledbackground',disabledBackgroundColor);	
    document.body.style.setProperty('--color-disabledtext',disabledTextColor);	
}

/// <summary>
/// Convert the Color object to string in hexadecimal format;
/// </summary>
function toHex(color, delta) {
    function computeValue(value, delta) {
        var computedValue = !isNaN(delta) ? value + delta : value;
        if (computedValue < 0)
            computedValue = 0;
        else if (computedValue > 255)
            computedValue = 255;

        computedValue = computedValue.toString(16);

        return computedValue.length == 1 ? '0' + computedValue : computedValue;
    }

    var hex = '';

    if (color) {
        with (color) {
            hex = computeValue(red, delta) + computeValue(green, delta) + computeValue(blue, delta);
        };
    }

    return '#' + hex;
}

/// <summary>
/// Call back for app theme color change.
/// </summary>
function onAppThemeColorChanged(event) {
    // Should get a latest HostEnvironment object from application.
    var skinInfo = JSON.parse(window.__adobe_cep__.getHostEnvironment()).appSkinInfo;

    // Gets the style information such as color info from the skinInfo, 
    // and redraw all UI controls of your extension according to the style info.
    updateThemeWithAppSkinInfo(skinInfo);
}